@@ -3,7 +3,7 @@ navbar_proj(
   do.call(
     navbarPage,
     c(
-      "Radiant",
+      "Radiant for R",
       getOption("radiant.nav_ui"),
       getOption("radiant.multivariate_ui"),
       getOption("radiant.shared_ui"),
